window.Gleam.initSearch([{"doc":"glexec","title":"glexec","content":"# gleam_erlexec\n\n[![Package Version](https://img.shields.io/hexpm/v/gleam_erlexec)](https://hex.pm/packages/gleam_erlexec)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleam_erlexec/)\n\nA wrapper around the functions found in\n[erlexec](https://hexdocs.pm/erlexec/exec.html).\n\nIt probably goes without saying, but this functionality is only available when\nrunnning on BEAM.\n\n## Quick start\n\n```gleam\nimport gleam/erlexec as exec\n\npub fn main() {\n  assert Ok(bash) = exec.find_executable(&quot;bash&quot;)\n\n  assert Ok(exec.Pids(_pid, ospid)) =\n    exec.new()\n    |&gt; exec.with_stdin(exec.StdinPipe)\n    |&gt; exec.with_stdout(exec.StdoutCapture)\n    |&gt; exec.with_stderr(exec.StderrStdout)\n    |&gt; exec.with_monitor(True)\n    |&gt; exec.with_pty(True)\n    |&gt; exec.run_async(exec.Execve([bash, &quot;-c&quot;, &quot;echo started &amp;&amp; cat&quot;]))\n\n  assert Ok(exec.ObtainStdout(_, &quot;started\\r\\n&quot;)) = exec.obtain(500)\n  assert Ok(Nil) = exec.send(ospid, &quot;test\\n&quot;)\n  assert Ok(exec.ObtainStdout(_, &quot;test\\r\\n&quot;)) = exec.obtain(500)\n  assert Ok(Nil) = exec.kill_ospid(ospid, 9)\n}\n```\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add gleam_erlexec\n```\n\n## Development\n\n```sh\ngleam test  # Run the tests\ngleam run   # Run a small example\ngleam shell # Run an Erlang shell\n```\n\n## TODO\n\nThe test suite is still fairly incomplete, but without code coverage it is a\nbit hard to ensure all cases are covered and the main functionality is tested\nin `erlexec` itself.\n\nHappy for any PRs though.\n","url":"index.html"},{"doc":"gleam/erlexec","title":"Command","content":"pub type Command {\n  Shell(String)\n  Execve(List(String))\n}\n Command to be executed.\nShell(String)\n The specified command will be executed through the shell. The current shell\n is obtained from environment variable `SHELL`.\n\n This can be useful primarily for the enhanced control flow it offers over\n most system shells and still want convenient access to other shell features\n such as shell pipes, filename wildcards, environment variable expansion,\n and expansion of `~` to a user&#39;s home directory. All command arguments must\n be properly escaped including whitespace and shell metacharacters.\n\n Warning: Executing shell commands that incorporate unsanitized input from\n an untrusted source makes a program vulnerable to shell injection, a\n serious security flaw which can result in arbitrary command execution. For\n this reason, the use of shell is strongly discouraged in cases where the\n command string is constructed from external input. \n\nExecve(List(String))\n Command is passed to `execve(3)` library call directly without involving\n the shell process, so the list of strings represents the program to be\n executed with arguments. In this case all shell-based features are disabled\n and there&#39;s no shell injection vulnerability.\n\nSynonyms:\ngleam/erlexec.Command\ngleam/erlexec Command","url":"gleam/erlexec.html#Command"},{"doc":"gleam/erlexec","title":"EnvOption","content":"pub type EnvOption {\n  EnvString(String)\n  EnvClear\n  EnvKV(String, String)\n  EnvUnset(String)\n}\n\nEnvString(String)\n\n\nEnvClear\n\n\nEnvKV(String, String)\n\n\nEnvUnset(String)\n\n\nSynonyms:\ngleam/erlexec.EnvOption\ngleam/erlexec EnvOption","url":"gleam/erlexec.html#EnvOption"},{"doc":"gleam/erlexec","title":"EnvOptions","content":"pub type EnvOptions =\n  List(EnvOption)\n\n\nSynonyms:\ngleam/erlexec.EnvOptions\ngleam/erlexec EnvOptions","url":"gleam/erlexec.html#EnvOptions"},{"doc":"gleam/erlexec","title":"ExitStatusOrSignal","content":"pub type ExitStatusOrSignal {\n  ExitStatus(Int)\n  Signal(status: Signal, core_dump: Bool)\n}\n\nExitStatus(Int)\n\n\nSignal(status: Signal, core_dump: Bool)\n\n\nSynonyms:\ngleam/erlexec.ExitStatusOrSignal\ngleam/erlexec ExitStatusOrSignal","url":"gleam/erlexec.html#ExitStatusOrSignal"},{"doc":"gleam/erlexec","title":"FindExecutableError","content":"pub type FindExecutableError {\n  ExecutableNotFound\n}\n\nExecutableNotFound\n\n\nSynonyms:\ngleam/erlexec.FindExecutableError\ngleam/erlexec FindExecutableError","url":"gleam/erlexec.html#FindExecutableError"},{"doc":"gleam/erlexec","title":"ObtainError","content":"pub type ObtainError {\n  ObtainTimeout\n  ObtainDownStatus(Pid, OsPid, Int)\n}\n\nObtainTimeout\n\n\nObtainDownStatus(Pid, OsPid, Int)\n\n\nSynonyms:\ngleam/erlexec.ObtainError\ngleam/erlexec ObtainError","url":"gleam/erlexec.html#ObtainError"},{"doc":"gleam/erlexec","title":"ObtainOk","content":"pub type ObtainOk {\n  ObtainStdout(Int, String)\n  ObtainStderr(Int, String)\n  ObtainDown(Pid, OsPid)\n}\n\nObtainStdout(Int, String)\n\n\nObtainStderr(Int, String)\n\n\nObtainDown(Pid, OsPid)\n\n\nSynonyms:\ngleam/erlexec.ObtainOk\ngleam/erlexec ObtainOk","url":"gleam/erlexec.html#ObtainOk"},{"doc":"gleam/erlexec","title":"Options","content":"pub opaque type Options\n Keeps track of all the options that will be passed to\n [run_async](#run_async) or [run_sync](#run_sync)\n\nSynonyms:\ngleam/erlexec.Options\ngleam/erlexec Options","url":"gleam/erlexec.html#Options"},{"doc":"gleam/erlexec","title":"OsGid","content":"pub type OsGid =\n  Int\n Representation of OS group ID\n\nSynonyms:\ngleam/erlexec.OsGid\ngleam/erlexec OsGid","url":"gleam/erlexec.html#OsGid"},{"doc":"gleam/erlexec","title":"OsPid","content":"pub type OsPid =\n  Int\n Representation of OS process ID\n\nSynonyms:\ngleam/erlexec.OsPid\ngleam/erlexec OsPid","url":"gleam/erlexec.html#OsPid"},{"doc":"gleam/erlexec","title":"Output","content":"pub type Output {\n  Output(List(StdoutOrStderr))\n}\n\nOutput(List(StdoutOrStderr))\n\n\nSynonyms:\ngleam/erlexec.Output\ngleam/erlexec Output","url":"gleam/erlexec.html#Output"},{"doc":"gleam/erlexec","title":"Pids","content":"pub type Pids {\n  Pids(Pid, OsPid)\n}\n\nPids(Pid, OsPid)\n `Pid` is the Erlang process identifier.\n `OsPid` is the OS process identifier of the new process.\n\nSynonyms:\ngleam/erlexec.Pids\ngleam/erlexec Pids","url":"gleam/erlexec.html#Pids"},{"doc":"gleam/erlexec","title":"PtyOption","content":"pub type PtyOption {\n  Vintr(Int)\n  Vquit(Int)\n  Verase(Int)\n  Vkill(Int)\n  Veof(Int)\n  Veol(Int)\n  Veol2(Int)\n  Vstart(Int)\n  Vstop(Int)\n  Vsusp(Int)\n  Vdsusp(Int)\n  Vreprint(Int)\n  Vwerase(Int)\n  Vlnext(Int)\n  Vflush(Int)\n  Vswtch(Int)\n  Vstatus(Int)\n  Vdiscard(Int)\n  Ignpar(Bool)\n  Parmrk(Bool)\n  Inpck(Bool)\n  Istrip(Bool)\n  Inlcr(Bool)\n  Igncr(Bool)\n  Icrnl(Bool)\n  Xcase(Bool)\n  Iuclc(Bool)\n  Ixon(Bool)\n  Ixany(Bool)\n  Ixoff(Bool)\n  Imaxbel(Bool)\n  Iutf8(Bool)\n  Isig(Bool)\n  Icanon(Bool)\n  Echo(Bool)\n  Echoe(Bool)\n  Echok(Bool)\n  Echonl(Bool)\n  Noflsh(Bool)\n  Tostop(Bool)\n  Iexten(Bool)\n  Echoctl(Bool)\n  Echoke(Bool)\n  Pendin(Bool)\n  Opost(Bool)\n  Olcuc(Bool)\n  Onlcr(Bool)\n  Ocrnl(Bool)\n  Onocr(Bool)\n  Onlret(Bool)\n  Cs7(Bool)\n  Cs8(Bool)\n  Parenb(Bool)\n  Parodd(Bool)\n  TtyOpIspeed(Int)\n  TtyOpOspeed(Int)\n}\n For documentation please check:\n - [termios(3)](https://man7.org/linux/man-pages/man3/termios.3.html)\n - [RFC4254](https://datatracker.ietf.org/doc/html/rfc4254#section-8)\nVintr(Int)\n\n\nVquit(Int)\n\n\nVerase(Int)\n\n\nVkill(Int)\n\n\nVeof(Int)\n\n\nVeol(Int)\n\n\nVeol2(Int)\n\n\nVstart(Int)\n\n\nVstop(Int)\n\n\nVsusp(Int)\n\n\nVdsusp(Int)\n\n\nVreprint(Int)\n\n\nVwerase(Int)\n\n\nVlnext(Int)\n\n\nVflush(Int)\n\n\nVswtch(Int)\n\n\nVstatus(Int)\n\n\nVdiscard(Int)\n\n\nIgnpar(Bool)\n\n\nParmrk(Bool)\n\n\nInpck(Bool)\n\n\nIstrip(Bool)\n\n\nInlcr(Bool)\n\n\nIgncr(Bool)\n\n\nIcrnl(Bool)\n\n\nXcase(Bool)\n\n\nIuclc(Bool)\n\n\nIxon(Bool)\n\n\nIxany(Bool)\n\n\nIxoff(Bool)\n\n\nImaxbel(Bool)\n\n\nIutf8(Bool)\n\n\nIsig(Bool)\n\n\nIcanon(Bool)\n\n\nEcho(Bool)\n\n\nEchoe(Bool)\n\n\nEchok(Bool)\n\n\nEchonl(Bool)\n\n\nNoflsh(Bool)\n\n\nTostop(Bool)\n\n\nIexten(Bool)\n\n\nEchoctl(Bool)\n\n\nEchoke(Bool)\n\n\nPendin(Bool)\n\n\nOpost(Bool)\n\n\nOlcuc(Bool)\n\n\nOnlcr(Bool)\n\n\nOcrnl(Bool)\n\n\nOnocr(Bool)\n\n\nOnlret(Bool)\n\n\nCs7(Bool)\n\n\nCs8(Bool)\n\n\nParenb(Bool)\n\n\nParodd(Bool)\n\n\nTtyOpIspeed(Int)\n\n\nTtyOpOspeed(Int)\n\n\nSynonyms:\ngleam/erlexec.PtyOption\ngleam/erlexec PtyOption","url":"gleam/erlexec.html#PtyOption"},{"doc":"gleam/erlexec","title":"PtyOptions","content":"pub type PtyOptions {\n  PtyEnable\n  PtyOpts(List(PtyOption))\n}\n\nPtyEnable\n\n\nPtyOpts(List(PtyOption))\n\n\nSynonyms:\ngleam/erlexec.PtyOptions\ngleam/erlexec PtyOptions","url":"gleam/erlexec.html#PtyOptions"},{"doc":"gleam/erlexec","title":"Signal","content":"pub type Signal {\n  SIGHUP\n  SIGINT\n  SIGQUIT\n  SIGILL\n  SIGTRAP\n  SIGABRT\n  SIGBUS\n  SIGFPE\n  SIGKILL\n  SIGUSR1\n  SIGSEGV\n  SIGUSR2\n  SIGPIPE\n  SIGALRM\n  SIGTERM\n  SIGSTKFLT\n  SIGCHLD\n  SIGCONT\n  SIGSTOP\n  SIGTSTP\n  SIGTTIN\n  SIGTTOU\n  SIGURG\n  SIGXCPU\n  SIGXFSZ\n  SIGVTALRM\n  SIGPROF\n  SIGWINCH\n  SIGIO\n  SIGPWR\n  SIGSYS\n  Other(Int)\n}\n\nSIGHUP\n\n\nSIGINT\n\n\nSIGQUIT\n\n\nSIGILL\n\n\nSIGTRAP\n\n\nSIGABRT\n\n\nSIGBUS\n\n\nSIGFPE\n\n\nSIGKILL\n\n\nSIGUSR1\n\n\nSIGSEGV\n\n\nSIGUSR2\n\n\nSIGPIPE\n\n\nSIGALRM\n\n\nSIGTERM\n\n\nSIGSTKFLT\n\n\nSIGCHLD\n\n\nSIGCONT\n\n\nSIGSTOP\n\n\nSIGTSTP\n\n\nSIGTTIN\n\n\nSIGTTOU\n\n\nSIGURG\n\n\nSIGXCPU\n\n\nSIGXFSZ\n\n\nSIGVTALRM\n\n\nSIGPROF\n\n\nSIGWINCH\n\n\nSIGIO\n\n\nSIGPWR\n\n\nSIGSYS\n\n\nOther(Int)\n\n\nSynonyms:\ngleam/erlexec.Signal\ngleam/erlexec Signal","url":"gleam/erlexec.html#Signal"},{"doc":"gleam/erlexec","title":"StartError","content":"pub type StartError {\n  AlreadyStarted(Pid)\n}\n\nAlreadyStarted(Pid)\n\n\nSynonyms:\ngleam/erlexec.StartError\ngleam/erlexec StartError","url":"gleam/erlexec.html#StartError"},{"doc":"gleam/erlexec","title":"StartOption","content":"pub type StartOption {\n  StartDebug(level: Int)\n  StartRoot(enable: Bool)\n  StartVerbose\n  StartArgs(List(String))\n  StartAlarm(seconds: Int)\n  StartUser(String)\n  StartLimitUsers(List(String))\n  StartPortexe(String)\n  StartEnv(EnvOptions)\n}\n\nStartDebug(level: Int)\n\n\nStartRoot(enable: Bool)\n\n\nStartVerbose\n\n\nStartArgs(List(String))\n\n\nStartAlarm(seconds: Int)\n\n\nStartUser(String)\n\n\nStartLimitUsers(List(String))\n\n\nStartPortexe(String)\n\n\nStartEnv(EnvOptions)\n\n\nSynonyms:\ngleam/erlexec.StartOption\ngleam/erlexec StartOption","url":"gleam/erlexec.html#StartOption"},{"doc":"gleam/erlexec","title":"StderrOptions","content":"pub type StderrOptions {\n  StderrCapture\n  StderrClose\n  StderrFun(fn(Atom, Int, String) -&gt; Nil)\n  StderrNull\n  StderrPid(Pid)\n  StderrPrint\n  StderrStdout\n  StderrString(String)\n}\n\nStderrCapture\n\n\nStderrClose\n\n\nStderrFun(fn(Atom, Int, String) -&gt; Nil)\n\n\nStderrNull\n\n\nStderrPid(Pid)\n\n\nStderrPrint\n\n\nStderrStdout\n\n\nStderrString(String)\n\n\nSynonyms:\ngleam/erlexec.StderrOptions\ngleam/erlexec StderrOptions","url":"gleam/erlexec.html#StderrOptions"},{"doc":"gleam/erlexec","title":"StdinOptions","content":"pub type StdinOptions {\n  StdinClose\n  StdinNull\n  StdinPipe\n  StdinFrom(String)\n}\n\nStdinClose\n\n\nStdinNull\n\n\nStdinPipe\n\n\nStdinFrom(String)\n\n\nSynonyms:\ngleam/erlexec.StdinOptions\ngleam/erlexec StdinOptions","url":"gleam/erlexec.html#StdinOptions"},{"doc":"gleam/erlexec","title":"StdoutOptions","content":"pub type StdoutOptions {\n  StdoutCapture\n  StdoutClose\n  StdoutFun(fn(Atom, Int, String) -&gt; Nil)\n  StdoutNull\n  StdoutPid(Pid)\n  StdoutPrint\n  StdoutStderr\n  StdoutString(String)\n}\n\nStdoutCapture\n\n\nStdoutClose\n\n\nStdoutFun(fn(Atom, Int, String) -&gt; Nil)\n\n\nStdoutNull\n\n\nStdoutPid(Pid)\n\n\nStdoutPrint\n\n\nStdoutStderr\n\n\nStdoutString(String)\n\n\nSynonyms:\ngleam/erlexec.StdoutOptions\ngleam/erlexec StdoutOptions","url":"gleam/erlexec.html#StdoutOptions"},{"doc":"gleam/erlexec","title":"StdoutOrStderr","content":"pub type StdoutOrStderr {\n  Stdout(List(String))\n  Stderr(List(String))\n}\n\nStdout(List(String))\n\n\nStderr(List(String))\n\n\nSynonyms:\ngleam/erlexec.StdoutOrStderr\ngleam/erlexec StdoutOrStderr","url":"gleam/erlexec.html#StdoutOrStderr"},{"doc":"gleam/erlexec","title":"StopError","content":"pub type StopError {\n  NoProcess\n}\n\nNoProcess\n\n\nSynonyms:\ngleam/erlexec.StopError\ngleam/erlexec StopError","url":"gleam/erlexec.html#StopError"},{"doc":"gleam/erlexec","title":"debug","content":"pub fn debug(level: Int) -&gt; Result(Int, Atom)\n Set the global debug level\nSynonyms:\ngleam/erlexec.debug\ngleam/erlexec debug","url":"gleam/erlexec.html#debug"},{"doc":"gleam/erlexec","title":"find_executable","content":"pub fn find_executable(\n  name: String,\n) -&gt; Result(String, FindExecutableError)\n Tries to find the given executable name and returns the full path to it.\nSynonyms:\ngleam/erlexec.find_executable\ngleam/erlexec find_executable","url":"gleam/erlexec.html#find_executable"},{"doc":"gleam/erlexec","title":"get_cd","content":"pub fn get_cd(options: Options) -&gt; Option(String)\n\nSynonyms:\ngleam/erlexec.get_cd\ngleam/erlexec get_cd","url":"gleam/erlexec.html#get_cd"},{"doc":"gleam/erlexec","title":"get_env","content":"pub fn get_env(options: Options) -&gt; List(EnvOption)\n\nSynonyms:\ngleam/erlexec.get_env\ngleam/erlexec get_env","url":"gleam/erlexec.html#get_env"},{"doc":"gleam/erlexec","title":"get_executable","content":"pub fn get_executable(options: Options) -&gt; Option(String)\n\nSynonyms:\ngleam/erlexec.get_executable\ngleam/erlexec get_executable","url":"gleam/erlexec.html#get_executable"},{"doc":"gleam/erlexec","title":"get_kill","content":"pub fn get_kill(options: Options) -&gt; Option(String)\n\nSynonyms:\ngleam/erlexec.get_kill\ngleam/erlexec get_kill","url":"gleam/erlexec.html#get_kill"},{"doc":"gleam/erlexec","title":"get_link","content":"pub fn get_link(options: Options) -&gt; Bool\n\nSynonyms:\ngleam/erlexec.get_link\ngleam/erlexec get_link","url":"gleam/erlexec.html#get_link"},{"doc":"gleam/erlexec","title":"get_monitor","content":"pub fn get_monitor(options: Options) -&gt; Bool\n\nSynonyms:\ngleam/erlexec.get_monitor\ngleam/erlexec get_monitor","url":"gleam/erlexec.html#get_monitor"},{"doc":"gleam/erlexec","title":"get_pty","content":"pub fn get_pty(options: Options) -&gt; Bool\n\nSynonyms:\ngleam/erlexec.get_pty\ngleam/erlexec get_pty","url":"gleam/erlexec.html#get_pty"},{"doc":"gleam/erlexec","title":"get_stderr","content":"pub fn get_stderr(options: Options) -&gt; Option(StderrOptions)\n\nSynonyms:\ngleam/erlexec.get_stderr\ngleam/erlexec get_stderr","url":"gleam/erlexec.html#get_stderr"},{"doc":"gleam/erlexec","title":"get_stdin","content":"pub fn get_stdin(options: Options) -&gt; Option(StdinOptions)\n\nSynonyms:\ngleam/erlexec.get_stdin\ngleam/erlexec get_stdin","url":"gleam/erlexec.html#get_stdin"},{"doc":"gleam/erlexec","title":"get_stdout","content":"pub fn get_stdout(options: Options) -&gt; Option(StdoutOptions)\n\nSynonyms:\ngleam/erlexec.get_stdout\ngleam/erlexec get_stdout","url":"gleam/erlexec.html#get_stdout"},{"doc":"gleam/erlexec","title":"int_to_signal","content":"pub fn int_to_signal(signal: Int) -&gt; Signal\n\nSynonyms:\ngleam/erlexec.int_to_signal\ngleam/erlexec int_to_signal","url":"gleam/erlexec.html#int_to_signal"},{"doc":"gleam/erlexec","title":"kill_ospid","content":"pub fn kill_ospid(\n  ospid: Int,\n  signal: Int,\n) -&gt; Result(Nil, Dynamic)\n Send a signal to an OsPid.\nSynonyms:\ngleam/erlexec.kill_ospid\ngleam/erlexec kill_ospid","url":"gleam/erlexec.html#kill_ospid"},{"doc":"gleam/erlexec","title":"kill_pid","content":"pub fn kill_pid(pid: Pid, signal: Int) -&gt; Result(Nil, Dynamic)\n Send a signal to a child Pid.\nSynonyms:\ngleam/erlexec.kill_pid\ngleam/erlexec kill_pid","url":"gleam/erlexec.html#kill_pid"},{"doc":"gleam/erlexec","title":"manage_pid","content":"pub fn manage_pid(pid: Pid, options: Options) -&gt; Dynamic\n\nSynonyms:\ngleam/erlexec.manage_pid\ngleam/erlexec manage_pid","url":"gleam/erlexec.html#manage_pid"},{"doc":"gleam/erlexec","title":"new","content":"pub fn new() -&gt; Options\n Initial constructor for Options. Changing these settings is done with the\n `with_*` functions.\nSynonyms:\ngleam/erlexec.new\ngleam/erlexec new","url":"gleam/erlexec.html#new"},{"doc":"gleam/erlexec","title":"obtain","content":"pub fn obtain(\n  timeout_in_milliseconds: Int,\n) -&gt; Result(ObtainOk, ObtainError)\n\nSynonyms:\ngleam/erlexec.obtain\ngleam/erlexec obtain","url":"gleam/erlexec.html#obtain"},{"doc":"gleam/erlexec","title":"options_to_list","content":"pub fn options_to_list(options: Options) -&gt; List(Dynamic)\n\nSynonyms:\ngleam/erlexec.options_to_list\ngleam/erlexec options_to_list","url":"gleam/erlexec.html#options_to_list"},{"doc":"gleam/erlexec","title":"run_async","content":"pub fn run_async(\n  options: Options,\n  command: Command,\n) -&gt; Result(Pids, String)\n Run command with the given options, don&#39;t wait for it to finish.\nSynonyms:\ngleam/erlexec.run_async\ngleam/erlexec run_async","url":"gleam/erlexec.html#run_async"},{"doc":"gleam/erlexec","title":"run_sync","content":"pub fn run_sync(\n  options: Options,\n  command: Command,\n) -&gt; Result(Output, String)\n Run command with the given options, block the caller until it exits.\nSynonyms:\ngleam/erlexec.run_sync\ngleam/erlexec run_sync","url":"gleam/erlexec.html#run_sync"},{"doc":"gleam/erlexec","title":"send","content":"pub fn send(ospid: Int, data: String) -&gt; Result(Nil, Dynamic)\n\nSynonyms:\ngleam/erlexec.send\ngleam/erlexec send","url":"gleam/erlexec.html#send"},{"doc":"gleam/erlexec","title":"send_eof","content":"pub fn send_eof(ospid: Int) -&gt; Result(Nil, Dynamic)\n This will close `stdin`.\nSynonyms:\ngleam/erlexec.send_eof\ngleam/erlexec send_eof","url":"gleam/erlexec.html#send_eof"},{"doc":"gleam/erlexec","title":"signal_to_int","content":"pub fn signal_to_int(signal: Signal) -&gt; Int\n\nSynonyms:\ngleam/erlexec.signal_to_int\ngleam/erlexec signal_to_int","url":"gleam/erlexec.html#signal_to_int"},{"doc":"gleam/erlexec","title":"start","content":"pub fn start(\n  options: List(StartOption),\n) -&gt; Result(Pid, StartError)\n Start the `exec` application\nSynonyms:\ngleam/erlexec.start\ngleam/erlexec start","url":"gleam/erlexec.html#start"},{"doc":"gleam/erlexec","title":"status","content":"pub fn status(status: Int) -&gt; ExitStatusOrSignal\n  Decode the program&#39;s exit_status.\n\n  If the program exited by signal the function returns [Signal](#Signal),\n  otherwise it will return an [ExitStatus](#ExitStatus)\nSynonyms:\ngleam/erlexec.status\ngleam/erlexec status","url":"gleam/erlexec.html#status"},{"doc":"gleam/erlexec","title":"stop","content":"pub fn stop(pid: Int) -&gt; Result(Nil, Dynamic)\n Terminate a managed `Pid`, `OsPid`, or Port process.\n The OS process is terminated gracefully. If it was given a `{kill, Cmd}`\n option at startup, that command is executed and a timer is started. If the\n program doesn&#39;t exit, then the default termination is performed. Default\n termination implies sending a `SIGTERM` command followed by a `SIGKILL` in 5\n seconds, if the program doesn&#39;t get killed.\nSynonyms:\ngleam/erlexec.stop\ngleam/erlexec stop","url":"gleam/erlexec.html#stop"},{"doc":"gleam/erlexec","title":"to_ospid","content":"pub fn to_ospid(ospid: Pid) -&gt; Result(Int, Dynamic)\n\nSynonyms:\ngleam/erlexec.to_ospid\ngleam/erlexec to_ospid","url":"gleam/erlexec.html#to_ospid"},{"doc":"gleam/erlexec","title":"which_children","content":"pub fn which_children() -&gt; List(Int)\n Get a list of children OsPids managed by the port program.\nSynonyms:\ngleam/erlexec.which_children\ngleam/erlexec which_children","url":"gleam/erlexec.html#which_children"},{"doc":"gleam/erlexec","title":"winsz","content":"pub fn winsz(\n  pid: Int,\n  rows: Int,\n  columns: Int,\n) -&gt; Result(Nil, Nil)\n\nSynonyms:\ngleam/erlexec.winsz\ngleam/erlexec winsz","url":"gleam/erlexec.html#winsz"},{"doc":"gleam/erlexec","title":"with_cd","content":"pub fn with_cd(old: Options, given: String) -&gt; Options\n Set a working directory\nSynonyms:\ngleam/erlexec.with_cd\ngleam/erlexec with_cd","url":"gleam/erlexec.html#with_cd"},{"doc":"gleam/erlexec","title":"with_debug","content":"pub fn with_debug(old: Options, level: Int) -&gt; Options\n Configure debug printing for this command.\n\n The `level` should be `0 &lt;= level =&lt; 10`\nSynonyms:\ngleam/erlexec.with_debug\ngleam/erlexec with_debug","url":"gleam/erlexec.html#with_debug"},{"doc":"gleam/erlexec","title":"with_env","content":"pub fn with_env(old: Options, given: List(EnvOption)) -&gt; Options\n Modify the program environment. See [EnvOption](#EnvOption)\nSynonyms:\ngleam/erlexec.with_env\ngleam/erlexec with_env","url":"gleam/erlexec.html#with_env"},{"doc":"gleam/erlexec","title":"with_executable","content":"pub fn with_executable(old: Options, given: String) -&gt; Options\n Specifies a replacement program to execute.\n\n It is very seldom needed. When the port program executes a child process\n using `execve(3)` call, the call takes the following arguments:\n `(executable, args, env)`.\n When the `command` argument is specified as the list of strings, the\n executable replaces the first parameter in the call, and the original\n `args` provided in the `command` parameter are passed as as the second\n parameter.\n Most programs treat the program specified by `args` as the command name,\n which can then be different from the program actually executed.\n \n ### Unix specific:\n\n The `args` name becomes the display name for the executable in utilities\n such as `ps`.\n\n If the `command` argument is a Shell, the `Executable` specifies a\n replacement shell for the default `/bin/sh`.\nSynonyms:\ngleam/erlexec.with_executable\ngleam/erlexec with_executable","url":"gleam/erlexec.html#with_executable"},{"doc":"gleam/erlexec","title":"with_group","content":"pub fn with_group(old: Options, given: Int) -&gt; Options\n Sets the effective group ID of the spawned process. The value `0` means to\n create a new group ID equal to the OS pid of the process.\nSynonyms:\ngleam/erlexec.with_group\ngleam/erlexec with_group","url":"gleam/erlexec.html#with_group"},{"doc":"gleam/erlexec","title":"with_kill","content":"pub fn with_kill(old: Options, command: String) -&gt; Options\n This command will be used for killing the process.\n\n If the process is still alive after 5 seconds, it receives a `SIGKILL`.\n\n The kill command will have a `CHILD_PID` environment variable set to the\n pid of the process it is expected to kill.\n\n If the `kill` option is not specified, by default first the command is sent\n a `SIGTERM` signal, followed by `SIGKILL` after a default timeout.\nSynonyms:\ngleam/erlexec.with_kill\ngleam/erlexec with_kill","url":"gleam/erlexec.html#with_kill"},{"doc":"gleam/erlexec","title":"with_kill_group","content":"pub fn with_kill_group(old: Options, given: Bool) -&gt; Options\n At process exit kill the whole process group associated with this pid.\n The process group is obtained by the call to `getpgid(3)`.\nSynonyms:\ngleam/erlexec.with_kill_group\ngleam/erlexec with_kill_group","url":"gleam/erlexec.html#with_kill_group"},{"doc":"gleam/erlexec","title":"with_kill_timeout","content":"pub fn with_kill_timeout(old: Options, given: Int) -&gt; Options\n Number of seconds to wait after issuing a SIGTERM or\n executing the custom `kill` command (if specified) before\n killing the process with the `SIGKILL` signal\nSynonyms:\ngleam/erlexec.with_kill_timeout\ngleam/erlexec with_kill_timeout","url":"gleam/erlexec.html#with_kill_timeout"},{"doc":"gleam/erlexec","title":"with_link","content":"pub fn with_link(old: Options, given: Bool) -&gt; Options\n Link to the OsPid. If OsPid exits, the calling process will be killed or if\n it&#39;s trapping exits, it&#39;ll get {&#39;EXIT&#39;, OsPid, Status} message.  If the\n calling process dies the OsPid will be killed.\n The `Status` can be decoded with [status](#status) to determine the\n process&#39;s exit code and if it was killed by signal.\nSynonyms:\ngleam/erlexec.with_link\ngleam/erlexec with_link","url":"gleam/erlexec.html#with_link"},{"doc":"gleam/erlexec","title":"with_monitor","content":"pub fn with_monitor(old: Options, given: Bool) -&gt; Options\n Set up a monitor for the spawned process.\n\n The monitor is not a standard `erlang:monitor/2` function call, but\n it&#39;s emulated by ensuring that the monitoring process receives\n notifications in the form:\n `{&#39;DOWN&#39;, OsPid::integer(), process, Pid::pid(), Reason}`.\n\n If the `Reason` is `normal`, then process exited with status `0`,\n otherwise there was an error. If the Reason is `{status, Status}` the\n returned `Status` can be decoded with the [status](#status) function to\n determine the exit code of the process and if it was killed by signal.\nSynonyms:\ngleam/erlexec.with_monitor\ngleam/erlexec with_monitor","url":"gleam/erlexec.html#with_monitor"},{"doc":"gleam/erlexec","title":"with_nice","content":"pub fn with_nice(old: Options, priority: Int) -&gt; Options\n Set process priority between `-20` and `20`. Note that negative values\n can be specified only when `exec-port` is started with a root suid bit\n set.\nSynonyms:\ngleam/erlexec.with_nice\ngleam/erlexec with_nice","url":"gleam/erlexec.html#with_nice"},{"doc":"gleam/erlexec","title":"with_pty","content":"pub fn with_pty(old: Options, enable_pty: Bool) -&gt; Options\n Use pseudo terminal for the process&#39;s stdin, stdout and stderr\nSynonyms:\ngleam/erlexec.with_pty\ngleam/erlexec with_pty","url":"gleam/erlexec.html#with_pty"},{"doc":"gleam/erlexec","title":"with_pty_echo","content":"pub fn with_pty_echo(old: Options, given: Bool) -&gt; Options\n Allow the pty to run in echo mode, disabled by default.\nSynonyms:\ngleam/erlexec.with_pty_echo\ngleam/erlexec with_pty_echo","url":"gleam/erlexec.html#with_pty_echo"},{"doc":"gleam/erlexec","title":"with_stderr","content":"pub fn with_stderr(old: Options, given: StderrOptions) -&gt; Options\n Configure `stderr` communication with the OS process.\n See [StderrOptions](#StderrOptions)\nSynonyms:\ngleam/erlexec.with_stderr\ngleam/erlexec with_stderr","url":"gleam/erlexec.html#with_stderr"},{"doc":"gleam/erlexec","title":"with_stdin","content":"pub fn with_stdin(old: Options, given: StdinOptions) -&gt; Options\n Configure `stdin` communication with the OS process.\n See [StdinOptions](#StdinOptions)\nSynonyms:\ngleam/erlexec.with_stdin\ngleam/erlexec with_stdin","url":"gleam/erlexec.html#with_stdin"},{"doc":"gleam/erlexec","title":"with_stdout","content":"pub fn with_stdout(old: Options, given: StdoutOptions) -&gt; Options\n Configure `stdout` communication with the OS process.\n See [StdoutOptions](#StdoutOptions)\nSynonyms:\ngleam/erlexec.with_stdout\ngleam/erlexec with_stdout","url":"gleam/erlexec.html#with_stdout"},{"doc":"gleam/erlexec","title":"with_success_exit_code","content":"pub fn with_success_exit_code(\n  old: Options,\n  given: Int,\n) -&gt; Options\n Return value on success.\nSynonyms:\ngleam/erlexec.with_success_exit_code\ngleam/erlexec with_success_exit_code","url":"gleam/erlexec.html#with_success_exit_code"},{"doc":"gleam/erlexec","title":"with_user","content":"pub fn with_user(old: Options, given: String) -&gt; Options\n When `exec-port` was compiled with capability (Linux) support enabled\n and has a suid bit set, it&#39;s capable of running commands with a\n different effective user. The value &quot;root&quot; is prohibited.\nSynonyms:\ngleam/erlexec.with_user\ngleam/erlexec with_user","url":"gleam/erlexec.html#with_user"},{"doc":"gleam/erlexec","title":"with_winsz","content":"pub fn with_winsz(\n  old: Options,\n  rows: Int,\n  columns: Int,\n) -&gt; Options\n\nSynonyms:\ngleam/erlexec.with_winsz\ngleam/erlexec with_winsz","url":"gleam/erlexec.html#with_winsz"},{"doc":"gleam/erlexec","title":"gleam/erlexec","content":" OS shell command runner. It communicates with a separate C++ port process\n exec-port spawned by this module, which is responsible for starting,\n killing, listing, terminating, and notifying of state changes.\n\n For more detailed documentation, please refer to\n https://hexdocs.pm/erlexec/exec.html","url":"gleam/erlexec.html"},{"doc":"gleam_erlexec","title":"main","content":"pub fn main() -&gt; Result(Nil, Dynamic)\n\nSynonyms:\ngleam_erlexec.main\ngleam_erlexec main","url":"gleam_erlexec.html#main"},{"doc":"gleam_erlexec","title":"gleam_erlexec","content":"","url":"gleam_erlexec.html"}]);